import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:sendtrain/classes/activity_action.dart';
import 'package:sendtrain/classes/media.dart';
import 'package:sendtrain/models/activity_model.dart';
import 'package:sendtrain/models/activity_timer_model.dart';
import 'package:sendtrain/widgets/activity_action_view.dart';
import 'package:sendtrain/widgets/media_card.dart';

class ActivityView extends StatefulWidget {
  ActivityView({super.key, required this.activity});
  ActivityModel activity;

  @override
  State<ActivityView> createState() => _ActivityViewState();
}

class _ActivityViewState extends State<ActivityView> {
  @override
  Widget build(BuildContext context) {
    ActivityModel activity = widget.activity;
    ActivityTimerModel atm =
        Provider.of<ActivityTimerModel>(context, listen: false);
    // ActivityActionView activityActionView =
    //     ActivityActionView(action: activity.actions[0]);

    if (atm.active == false) {
      atm.setupTimer(activity);
    }

    return Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
      AppBar(
        // surfaceTintColor: ThemeData.dark(useMaterial3: true).colorScheme.primary,
        // backgroundColor: ThemeData.dark(useMaterial3: true).colorScheme.primaryContainer,
        centerTitle: true,
        title: const Text('Activity', style: TextStyle(fontSize: 15)),
      ),
      Padding(
          padding:
              const EdgeInsets.only(left: 15, right: 20, top: 15, bottom: 10),
          child: Text(
              maxLines: 1,
              style: const TextStyle(fontSize: 25, fontWeight: FontWeight.bold),
              activity.title)),
      ActivityViewCategories(categories: activity.categories),
      Padding(
          padding:
              const EdgeInsets.only(top: 0, bottom: 20, left: 15, right: 15),
          child: Text(
              textAlign: TextAlign.left,
              style: const TextStyle(fontSize: 15),
              activity.description)),
      ActivityViewMedia(activity: activity),
      const Padding(
          padding: EdgeInsets.fromLTRB(15, 30, 0, 10),
          child: Text(
              textAlign: TextAlign.left,
              style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
              'Actions:')),
      ActivityActionView(action: activity.actions[0]),
      Container(
          height: MediaQuery.sizeOf(context).height * .07,
          color:
              ThemeData.dark(useMaterial3: true).colorScheme.primaryContainer,
          child: Row(children: [
            Expanded(
                flex: 1,
                child: Flex(direction: Axis.horizontal, children: [
                  IconButton(
                      iconSize: 30,
                      icon: const Icon(Icons.play_arrow_rounded),
                      onPressed: () => {
                        atm.startTimer()
                      }),
                  IconButton(
                      iconSize: 36,
                      icon: const Icon(Icons.skip_next_rounded),
                      onPressed: () {
                        atm.incrementAction();
                      })
                ])),
            Expanded(
                flex: 1,
                child: Consumer<ActivityTimerModel>(
                  builder: (context, atm, child) {
                    return Text(
                        style: const TextStyle(fontSize: 25),
                        textAlign: TextAlign.center,
                        '${atm.tickCount}');
                  },
                )),
            Expanded(
                flex: 1,
                child: Padding(
                    padding: const EdgeInsets.only(right: 10),
                    child: Consumer<ActivityTimerModel>(
                        builder: (context, atm, child) {
                      return Text(
                          style: const TextStyle(fontSize: 15),
                          textAlign: TextAlign.right,
                          'Set: ${atm.currentSet + 1}/${atm.totalSets}\nRep: ${atm.currentRep + 1}/${atm.totalReps}');
                    }))),
          ]))
    ]);
  }
}

class ActivityViewCategories extends StatelessWidget {
  const ActivityViewCategories({super.key, this.categories});

  final List<String>? categories;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Padding(
            padding: const EdgeInsets.only(bottom: 10),
            child: SizedBox(
                height: 40,
                child: ListView.builder(
                  shrinkWrap: true,
                  scrollDirection: Axis.horizontal,
                  padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                  itemCount: categories?.length,
                  itemBuilder: (BuildContext context, int index) {
                    return Padding(
                        padding: const EdgeInsets.only(right: 5),
                        child: ActionChip(
                          visualDensity: VisualDensity.compact,
                          avatar: const Icon(Icons.check_circle_outline),
                          label: Text(maxLines: 1, '${categories?[index]}'),
                          onPressed: () {},
                        ));
                  },
                ))),
      ],
    );
  }
}

class ActivityViewMedia extends StatelessWidget {
  const ActivityViewMedia({super.key, this.activity});

  final ActivityModel? activity;

  @override
  Widget build(BuildContext context) {
    List<Media> media = [];

    for (ActivityAction action in activity!.actions) {
      if (action.media!.isNotEmpty) {
        media.addAll(action.media as Iterable<Media>);
      }
    }

    List<Widget> mediaCards =
        List.generate(media.length, (i) => MediaCard(media: media[i]));

    return Column(
      children: [
        SizedBox(
            width: double.infinity,
            height: 100,
            child: GridView.count(
                padding: const EdgeInsets.fromLTRB(15, 0, 0, 0),
                scrollDirection: Axis.horizontal,
                crossAxisSpacing: 5,
                mainAxisSpacing: 5,
                crossAxisCount: 1,
                children: mediaCards))
      ],
    );
  }
}
